@@ -1,9 +1,6 @@
 /* lex.c
 
-   written by Don Maszle
-   10 October 1991
-
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.
+   Copyright (c) 1993-2008. Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -77,6 +74,31 @@ PSTR vrgszLexTypes[] = {
 /* routines */
 
 
+/* ----------------------------------------------------------------------------
+   CountChars
+
+   Count the number of characters of a stream (which must be already open) 
+   and reset the stream. 
+*/
+long CountChars (PFILE pFileIn)
+{
+  long nChars = 0;
+  char c;
+
+  /* keep reading as long as we have not reached eof */
+  while ((c = getc(pFileIn)) != EOF) {
+    nChars++;
+  }
+
+  rewind (pFileIn);
+
+  /* printf ("mod:countchars: nChars = %ld\n",nChars); */
+
+  return (nChars);
+
+} /* CountChars */
+
+
 /* ---------------------------------------------------------------------------
    ENextLex
 
@@ -288,14 +310,14 @@ long EvalUnary (PINPUTBUF pibIn, long index, PSTR *szExp, PSTR szToken,
    Return 0 on error, non-zero on success or EOF if at end of file.
 */
 
-int FillBuffer (PINPUTBUF pibIn)
+int FillBuffer (PINPUTBUF pibIn, long lBuffer_size)
 {
   int iReturn = 0;
   int iOffset;
 
   if (pibIn && pibIn->pfileIn && pibIn->pbufOrg) {
 
-    if ((iOffset = fread (pibIn->pbufOrg, 1, BUFFER_SIZE, pibIn->pfileIn))) {
+    if ((iOffset = fread (pibIn->pbufOrg, 1, lBuffer_size, pibIn->pfileIn))) {
       iReturn = (int) iOffset;
       PreventLexSplit (pibIn, iOffset);
       pibIn->pbufCur = pibIn->pbufOrg;
@@ -365,31 +387,51 @@ void GetToken (PSTR *szExp, PSTR szToken, PINT piType)
    Initializes the input buffer whose address is pibIn with the
    file given by szFullPathname, and fills the buffer array with the
    first data to be processed.
+   If a negative buffer size is given the buffer size is set to the 
+   length of the given input file.
+   Close the input file if the given size is -1 (it has been all read in).
+   Leave it open otherwise.
 
    Returns 0 on error, non-zero on success.
 */
 
-BOOL InitBuffer (PINPUTBUF pibIn, PSTR szFullPathname)
+BOOL InitBuffer (PINPUTBUF pibIn, long lSize, PSTR szFileIn)
 {
   BOOL bReturn = 0;
 
   if (!pibIn)
     return FALSE;
 
+  if (lSize < 0) {
+    if ((pibIn->pfileIn = fopen (szFileIn, "r"))) {
+      pibIn->lBufSize = CountChars (pibIn->pfileIn);
+      fclose (pibIn->pfileIn);
+    }
+    else
+      ReportError (pibIn, RE_FILENOTFOUND | RE_FATAL, szFileIn, NULL);
+  }
+  else
+    pibIn->lBufSize = lSize;
+
   pibIn->iLineNum = 1;
   pibIn->iLNPrev = 0;
   pibIn->cErrors = 0;
   pibIn->pInfo = NULL;
+  pibIn->pTempInfo = NULL;
   pibIn->pbufCur = NULL;
 
-  if ((pibIn->pfileIn = fopen (szFullPathname, "r"))) {
-    if ((pibIn->pbufOrg = (PBUF) malloc (BUFFER_SIZE)))
-      bReturn = FillBuffer (pibIn);
+  if ((pibIn->pfileIn = fopen (szFileIn, "r"))) {
+    if ((pibIn->pbufOrg = (PBUF) malloc (pibIn->lBufSize)))
+      bReturn = FillBuffer (pibIn, pibIn->lBufSize);
     else
       ReportError (pibIn, RE_OUTOFMEM | RE_FATAL, "InitBuffer", NULL);
   }
   else
-    ReportError (pibIn, RE_FILENOTFOUND | RE_FATAL, szFullPathname, NULL);
+    ReportError (pibIn, RE_FILENOTFOUND | RE_FATAL, szFileIn, NULL);
+
+  /* close input file eventually */
+  if (lSize < 0)
+    fclose (pibIn->pfileIn);
 
   return (bReturn);
 
@@ -404,16 +446,16 @@ BOOL InitBuffer (PINPUTBUF pibIn, PSTR szFullPathname)
 
 void MakeStringBuffer (PINPUTBUF pBuf, PINPUTBUF pbufStr, PSTR sz)
 {
-  pbufStr->pfileIn = NULL;        /* Flags that is not file buffer */
+  pbufStr->pfileIn = NULL; /* Flags that is not file buffer */
   pbufStr->pbufCur = pbufStr->pbufOrg = sz;
-  pbufStr->iLineNum = 0;        /* Multiline eqn formatting in modo */
+  pbufStr->iLineNum = 0; /* Multiline eqn formatting in modo */
   pbufStr->iLNPrev  = 0;
   pbufStr->pInfo = (pBuf ? pBuf->pInfo : NULL);
 
   if (pBuf) {
-    pbufStr->iLineNum = pBuf->iLineNum;    /* For error reporting  */
-    pbufStr->iLNPrev = TRUE;        /* Flag: Use iLineNum in ReportError */
-  } /* if */
+    pbufStr->iLineNum = pBuf->iLineNum; /* For error reporting  */
+    pbufStr->iLNPrev = TRUE; /* Flag: Use iLineNum in ReportError */
+  }
 
 } /* MakeStringBuffer */
 
@@ -498,9 +540,16 @@ void GetaString (PINPUTBUF pibIn, PSTR szLex)
 
     while ((*pibIn->pbufCur)
            && (*pibIn->pbufCur != CH_STRDELIM)
-           && (i < MAX_LEX-1));
+           && (i < MAX_LEX - 1));
   } /* if */
 
+  if (i == MAX_LEX - 1) {
+    printf ("\n***Error: max string length MAX_LEX exceeded in: %s\n",
+            szLex);
+    printf ("Exiting...\n\n");
+    exit (0);
+  }
+
   if (*pibIn->pbufCur == CH_STRDELIM) {
     pibIn->pbufCur++; /* Increment past closing delim */
     i--;
@@ -585,9 +634,9 @@ void GetIdentifier (PINPUTBUF pibIn, PSTR szLex)
     return;
 
   if (isalpha(*pibIn->pbufCur) || IsUnderscore(*pibIn->pbufCur)) {
-    do
-    szLex[i++] = *pibIn->pbufCur++; /* Copy identifier */
-
+    do {
+      szLex[i++] = *pibIn->pbufCur++; /* Copy identifier */
+    }
     while ((*pibIn->pbufCur)
            && (isalnum(*pibIn->pbufCur) || IsUnderscore(*pibIn->pbufCur))
            && (i < MAX_LEX-1));
@@ -832,9 +881,10 @@ void NextLex (PINPUTBUF pibIn, PSTRLEX szLex, PINT piLexType)
         if((c = *pibIn->pbufCur) != '=')
           szLex[1] = '\0';
         else if (szLex[0] == '!' || szLex[0] == '<' ||
-                 szLex[0] == '>' || szLex[0] == '=')
+                 szLex[0] == '>' || szLex[0] == '=') {
           szLex[1] = *pibIn->pbufCur++;
           szLex[2] = '\0';
+        }
       }
 
       else { /* Is other punctuation -- Take one char */
@@ -893,17 +943,17 @@ void SkipComment (PINPUTBUF pibIn)
     return;
 
   if (!*pibIn->pbufCur)
-    FillBuffer (pibIn);
+    FillBuffer (pibIn, BUFFER_SIZE);
 
   while (*pibIn->pbufCur++ != CH_EOLN) /* Eat 1 line comment */
     if (!*pibIn->pbufCur)
-      if (FillBuffer (pibIn) == EOF)
+      if (FillBuffer (pibIn, BUFFER_SIZE) == EOF)
     break;
 
   pibIn->iLineNum++;
 
   if (!*pibIn->pbufCur)
-    FillBuffer (pibIn);
+    FillBuffer (pibIn, BUFFER_SIZE);
 
 } /* SkipComment */
 
@@ -919,7 +969,7 @@ char NextChar (PINPUTBUF pibIn)
 {
   if (!pibIn
      || (!*pibIn->pbufCur
-         && FillBuffer (pibIn) == EOF))
+         && FillBuffer (pibIn, BUFFER_SIZE) == EOF))
     return (0);
 
   else
@@ -1063,7 +1113,7 @@ void GetStatement (PINPUTBUF pibIn, PSTR szStmt)
         }
       } /* if pibIn->pbufCur */
       else
-      fDone = (FillBuffer (pibIn) == EOF);
+      fDone = (FillBuffer (pibIn, BUFFER_SIZE) == EOF);
     } /* while */
 
     /* remove white spaces going backward - FB 28/2/98 */
@@ -1131,7 +1181,7 @@ int SkipWhitespace (PINPUTBUF pibIn)
     return 0;
 
   if (!*pibIn->pbufCur && pibIn->pfileIn)
-    FillBuffer (pibIn);
+    FillBuffer (pibIn, BUFFER_SIZE);
 
   /* Skip Spaces, Tabs and Newlines */
 
@@ -1142,11 +1192,11 @@ int SkipWhitespace (PINPUTBUF pibIn)
 
     else {
       if (c == '\n')
-    pibIn->iLineNum++;
+        pibIn->iLineNum++;
 
       if (!*(++pibIn->pbufCur) && pibIn->pfileIn)
-    if (FillBuffer (pibIn) == EOF)
-      break;
+        if (FillBuffer (pibIn, BUFFER_SIZE) == EOF)
+          break;
     } /* else */
   } /* while */
 
@@ -1203,7 +1253,7 @@ void UnrollEquation (PINPUTBUF pibIn, long index, PSTR szEqn, PSTR szEqnU)
         k++;
         m++;
       }
-    }
+    } /* end if bExpress */
     else switch (szEqn[j]) {
       case '[': /* replace by _ and enter expression parsing mode */
         szEqnU[k] = '_';
@@ -1225,11 +1275,12 @@ void UnrollEquation (PINPUTBUF pibIn, long index, PSTR szEqn, PSTR szEqnU)
   } /* while */
   if ((szEqn[j] != '\0') && (k == MAX_EQN - 1))
     ReportError (pibIn, RE_EQNTOOLONG | RE_FATAL, NULL, 
-                 "(Occured while unrolling a loop)");
+                 "(Occured in UnrollEquation)");
     
   /* terminate szEqnU */
   szEqnU[k] = '\0';
 
 } /* UnrollEquation */
 
+
 /* End */
