@@ -1,9 +1,6 @@
 /* lex.h
 
-   written by Don Maszle
-   13 October 1991
-   
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.
+   Copyright (c) 1993-2008. Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
