@@ -1,9 +1,6 @@
 /* lexfn.c
 
-   written by Don Maszle
-   15 October 1991
-   
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.
+   Copyright (c) 1993-2008. Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -33,14 +30,6 @@
    input functions which are shared between the model code generator
    facility and the simulation input routines.
    
-   This is in a separate file because it is not strictly part of the
-   lexical parser, yet is a shared feature between the two programs,
-   and thus should be encapsulated in one file.
-   
-   The code is slightly different for the two programs, though, with
-   the differences #ifdef'd using the symbol MODGEN to delimit the
-   model generator specific code.  This symbol needs to be defined in
-   the makefile.
 */
 
 #include <stdlib.h>
@@ -61,18 +50,10 @@
 
 #define IsIdentifier(sz)  ((sz) ? isalpha(*(sz)) || *(sz) == '_' : FALSE)
 
-#ifdef MODGEN /* Symbol table doesn't exist */
+HANDLE CalculateVarHandle (PVMMAPSTRCT pvm, PSTR sz);
+static PVMMAPSTRCT vpvmGlo; /* Global symbol table (yech) */
 
-  HANDLE CalculateVarHandle (PVMMAPSTRCT pvm, PSTR sz);
-  static PVMMAPSTRCT vpvmGlo; /* Global symbol table (yech) */
-
-  #define GetParmHandle(sz)  (CalculateVarHandle(vpvmGlo, (sz)))
-
-#else /* Call model utility routine */
-
-  #define GetParmHandle(sz)  (GetVarHandle((sz)))
-
-#endif
+#define GetParmHandle(sz)  (CalculateVarHandle(vpvmGlo, (sz)))
 
 
 /* Keyword Map Structure */
@@ -152,10 +133,7 @@ void InitIFN (PIFN pifn)
    Defines a parameter or a handle to a model parameter on which the
    parameter is dependent.  Returns TRUE on success.
 
-   NOTE:  The call to GetParmHandle() is actually a macro that is
-   dependent on whether or not the symbol MODGEN is defined,
-   that is, on whether or we are compiling the model generator
-   or the simulation. 
+   NOTE: The call to GetParmHandle() is actually a macro.
    
    If it is the simulation, GetParmHandle() should inquire
    into the symbol table for a handle to the dependent variable.
@@ -327,14 +305,12 @@ BOOL GetInputFn (PINPUTBUF pibIn, PSTR sz, PIFN pifn)
   if (!pibIn || !pifn)
     return (FALSE);
   
-#ifdef MODGEN 
   /* Define global variable map (yech) */
   {
     PINPUTINFO pinfo = (PINPUTINFO) pibIn->pInfo;
     
     vpvmGlo = pinfo->pvmGloVars;
   } /* block */
-#endif
   
   if (sz)
     MakeStringBuffer (pibIn, pibDum, sz);
