@@ -1,9 +1,6 @@
 /* modd.c
 
-   written by Don Robert Maszle
-   10 September 1991
-   
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.
+   Copyright (c) 1993-2008. Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -54,14 +51,15 @@ PSTR vrgszMathFuncs[] = {
   "floor", "fmod", "log", "log10", "pow", "sin", "sinh", "sqrt", "tan", "tanh",
 
   /* special functions defined in random.c */
-  "CDFNormal", "erfc", "lnDFNormal", "lnGamma", 
+  "CDFNormal", "erfc", "lnDFNormal", "lnGamma",
 
   /* random sampling related routines defined in random.c */
-  "BinomialRandom", "BetaRandom", "BinomialBetaRandom", "Chi2Random", 
-  "ExpRandom", "InvGGammaRandom", "GammaRandom", "GetSeed", "GGammaRandom",
+  "BetaRandom", "BinomialBetaRandom", "BinomialRandom", "CauchyRandom", 
+  "Chi2Random", 
+  "ExpRandom", "GammaRandom", "GetSeed", "GGammaRandom", "InvGGammaRandom", 
   "LogNormalRandom", "LogUniformRandom", "NormalRandom", "PiecewiseRandom",
-  "PoissonRandom", "SetSeed", "TruncLogNormalRandom", "TruncNormalRandom", 
-  "UniformRandom",
+  "PoissonRandom", "SetSeed", "StudentTRandom", "TruncInvGGammaRandom", 
+  "TruncLogNormalRandom", "TruncNormalRandom", "UniformRandom",
 
   /* End flag */
   ""
@@ -165,13 +163,12 @@ BOOL VerifyEqn (PINPUTBUF pibIn, PSTR szEqn)
 } /* VerifyEqn */
 
 
-
 /* ----------------------------------------------------------------------------
    AddEquation
    
    Adds an equation to the list given.  Note that this may be a
    variable table with initializer, or function defining equations.
-   
+ 
    The lists are maintained as stacks, i.e. Last one in is the head.
    This means that when writing equations to the output file, the
    pointers must first be reversed.  I know it's not brilliant and
@@ -338,7 +335,6 @@ HANDLE CalculateVarHandle (PVMMAPSTRCT pvm, PSTR sz)
 } /* CalculateVarHandle */
 
 
-
 /* ----------------------------------------------------------------------------
    DefineGlobalVar
    
@@ -398,7 +394,7 @@ void DefineGlobalVar (PINPUTBUF pibIn, PVMMAPSTRCT pvm,
 /* ----------------------------------------------------------------------------
    DefineDynamicsEqn
    
-   Defines an equation in the pvmDynEqn list.  State variable
+   Defines an equation in the pvmDynEqn list. State variable
    assignments are meant as derivative assignments.
 
    Redefinitions are reported, and ignored.
@@ -409,10 +405,9 @@ void DefineDynamicsEqn (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, HANDLE hType)
   HANDLE hNewType = (hType ? hType : ID_LOCALDYN);
   PINPUTINFO pinfo = (PINPUTINFO) pibIn->pInfo;
  
-  /* If there was more than one line since last equation, set ID_SPACEFLAG. 
-     This is kind of a kludge so I can use PVMMAPSTRCT struct. */
-  if (pibIn->iLineNum - pibIn->iLNPrev - 1)
-    hNewType |= ID_SPACEFLAG;
+  /* Set ID_SPACEFLAG. 
+     This is a terrible kludge so we can use PVMMAPSTRCT struct. */
+  hNewType |= ID_SPACEFLAG;
 
   if (!strcmp (szName, "Inline")) /* Inline statements are accumulated */
     AddEquation (&pinfo->pvmDynEqns, szName, szEqn, ID_INLINE);
@@ -536,15 +531,15 @@ void DefineJacobEqn (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, HANDLE hType)
    
    Define the variable szLex according to szEqn if the variable
    type is valid for the assignment in the given fContext.
-   
+
    * If iKWCode is KM_DXDT and the context is CN_DYNAMICS, defines a
      state equation for szName. States cannot be assigned direct
      values in the Dynamics section. 
      
    * Inputs cannot be assigned in the Dynamics section.
-   
+
    * Values given to States in a global context are initial values.
-   
+
    * In the global parameter declarations, a duplicate definition issues
      a warning and ignores the redefinitions
 */
@@ -600,7 +595,7 @@ void DefineVariable (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, int iKWCode)
     case CN_GLOBAL:
       DefineGlobalVar (pibIn, pvm, szName, szEqn, hGloVarType);
       break;
-    
+
     case CN_DYNAMICS:
       if (iKWCode == KM_DXDT)
         DefineDynamicsEqn (pibIn, szName, szEqn, ID_DERIV);
@@ -626,6 +621,7 @@ void DefineVariable (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, int iKWCode)
          CalcOutputs */
       if ((hGloVarType == ID_OUTPUT) || 
           (hGloVarType == ID_NULL) ||
+          (hGloVarType == ID_LOCALCALCOUT) || /* added 7 mar 2008 */
           (iKWCode == KM_INLINE))
         DefineCalcOutEqn (pibIn, szName, szEqn, hGloVarType);
       else
@@ -646,13 +642,13 @@ void DefineVariable (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, int iKWCode)
    DeclareModelVar
    
    Declares szName to be a model variable of the type indicated
-   by iKWCode.  Since the declaration commands States, Inputs, and
-   Outputs are only valid in the global context of the model 
+   by iKWCode. Since the declaration commands States, Inputs, Outputs
+   and Compartments are only valid in the global context of the model 
    description file, it should be assured that this procedure is only
    called in that context.
 
-   The number of States, Outputs, or Inputs is incremented, and 
-   nominal value and defining equations strings are initialized to NULL.
+   The number of States, Outputs, Inputs or Compartments is incremented, 
+   and nominal value and defining equations strings are initialized to NULL.
 */
 void DeclareModelVar (PINPUTBUF pibIn, PSTR szName, int iKWCode)
 {
@@ -661,26 +657,31 @@ void DeclareModelVar (PINPUTBUF pibIn, PSTR szName, int iKWCode)
   
   pinfo = (PINPUTINFO) pibIn->pInfo;
 
-  assert(iKWCode == KM_STATES || iKWCode == KM_INPUTS || iKWCode == KM_OUTPUTS);
+  assert (iKWCode == KM_STATES  || iKWCode == KM_INPUTS || 
+          iKWCode == KM_OUTPUTS || iKWCode == KM_COMPARTMENTS);
 
-  iKWCode = ((iKWCode == KM_STATES    ? ID_STATE /* Translate to ID_ */
-              : (iKWCode == KM_INPUTS ? ID_INPUT
-                                      : ID_OUTPUT)));
+  iKWCode = ((iKWCode == KM_STATES     ? ID_STATE /* Translate to ID_ */
+              : (iKWCode == KM_INPUTS  ? ID_INPUT
+              : (iKWCode == KM_OUTPUTS ? ID_OUTPUT
+                                       : ID_COMPARTMENT))));
 
-  if (!(hType = GetVarType (pinfo->pvmGloVars, szName))) /* New id */
-    AddEquation (&pinfo->pvmGloVars, szName, NULL, (HANDLE) iKWCode);
-
-  else if (hType == iKWCode) /* Same type redecl */
-    ReportError (pibIn, RE_DUPDECL | RE_WARNING, szName, NULL);
-
-  else 
-    if (hType == ID_PARM) { /* Already init'd */
-      ReportError (pibIn, RE_DUPDECL | RE_WARNING, szName,
-                   "Model variable initialized before declaration");
-      SetVarType (pinfo->pvmGloVars, szName, iKWCode);
-     
-    } /* if */
-    else /* Unresolvable conflict */
-      ReportError (pibIn, RE_DUPDECL | RE_FATAL, szName, NULL);
-  
+  if (!(hType = GetVarType (pinfo->pvmGloVars, szName))) { /* New id */
+    if (iKWCode == ID_COMPARTMENT)
+      AddEquation (&pinfo->pvmCpts, szName, NULL, (HANDLE) iKWCode);
+    else
+      AddEquation (&pinfo->pvmGloVars, szName, NULL, (HANDLE) iKWCode);
+  }
+  else {
+    if (hType == iKWCode) /* Same type redecl */
+      ReportError (pibIn, RE_DUPDECL | RE_WARNING, szName, NULL);
+    else {
+      if (hType == ID_PARM) { /* Already init'd */
+        ReportError (pibIn, RE_DUPDECL | RE_WARNING, szName,
+                     "Model variable initialized before declaration");
+        SetVarType (pinfo->pvmGloVars, szName, iKWCode);
+      }
+      else /* Unresolvable conflict */
+        ReportError (pibIn, RE_DUPDECL | RE_FATAL, szName, NULL);
+    }
+  }
 } /* DeclareModelVar */
