@@ -1,9 +1,6 @@
 /* modd.h
 
-   written by Frederic Bois
-   27 November 1997
-
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.
+   Copyright (c) 1993-2008. Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
