@@ -1,9 +1,6 @@
 /* modi.c
 
-   written by Don Robert Maszle
-   3 September 1991
-   
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.
+   Copyright (c) 1993-2008. Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -41,27 +38,32 @@
 #include "mod.h"
 #include "modd.h"
 #include "modi.h"
+#include "modiSBML.h"
   
 /* Global Keyword Map Structure */
 
 KM vrgkmKeywordMap[] = {
-  {"States",  KM_STATES,   CN_GLOBAL},
-  {"Inputs",  KM_INPUTS,   CN_GLOBAL},
-  {"Outputs", KM_OUTPUTS,  CN_GLOBAL},
+  {"States",       KM_STATES,       CN_GLOBAL},
+  {"Inputs",       KM_INPUTS,       CN_GLOBAL},
+  {"Outputs",      KM_OUTPUTS,      CN_GLOBAL},
+  {"Compartments", KM_COMPARTMENTS, CN_GLOBAL},
 
-  {"Dynamics",   KM_DYNAMICS, CN_GLOBAL},
-  {"Initialize", KM_SCALE,    CN_GLOBAL},
-  {"Scale",      KM_SCALE,    CN_GLOBAL}, /* obsolete */
-  {"Jacobian",   KM_JACOB,    CN_GLOBAL},
-  {"Jacob",      KM_JACOB,    CN_GLOBAL}, /* obsolete */
-  {"CalcOutputs",KM_CALCOUTPUTS,CN_CALCOUTPUTS},
+  {"Dynamics",     KM_DYNAMICS,     CN_GLOBAL},
+  {"Initialize",   KM_SCALE,        CN_GLOBAL},
+  {"Scale",        KM_SCALE,        CN_GLOBAL}, /* obsolete */
+  {"Jacobian",     KM_JACOB,        CN_GLOBAL},
+  {"Jacob",        KM_JACOB,        CN_GLOBAL}, /* obsolete */
+  {"CalcOutputs",  KM_CALCOUTPUTS,  CN_CALCOUTPUTS},
 
   /* Can be LHS only in Dynamics */
   {"dt", KM_DXDT,  CN_DYNAMICS | CN_INPUTDEF},
 
   {"Inline", KM_INLINE, CN_ALL},
+
+  {"SBMLModels", KM_SBMLMODELS, CN_GLOBAL | CN_TEMPLATE_DEFINED},
+  {"PKTemplate", KM_PKTEMPLATE, CN_GLOBAL},
   
-  {"End", KM_END,  CN_GLOBAL}, /* Optional End statement */
+  {"End", KM_END,  CN_GLOBAL | CN_TEMPLATE_DEFINED}, /* Optional End statmt */
 
   /* Variables names valid in all CN_ */
   {"", 0, CN_ALL} /* This marks the end of map too */
@@ -146,25 +148,10 @@ void GetVarList (PINPUTBUF pibIn, PSTR szLex, int iKWCode)
 } /* GetVarList */
 
 
-/* ----------------------------------------------------------------------------
-   InitInfo
-*/
-
-void InitInfo (PINPUTINFO pinfo, PSTR szInputFilename)
-{
-  pinfo->pvmGloVars = NULL;
-  pinfo->pvmDynEqns = NULL;
-  pinfo->pvmScaleEqns = NULL;
-  pinfo->pvmJacobEqns = NULL;
-  pinfo->pvmCalcOutEqns = NULL;
-  pinfo->wContext = CN_GLOBAL;
-  pinfo->szInputFilename = szInputFilename;
-  
-} /* InitInfo */
-
-
 /* ----------------------------------------------------------------------------
    ProcessDTStatement
+
+   process a differential equation definition
 */
 
 void ProcessDTStatement (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn, int iKWCode)
@@ -285,7 +272,8 @@ void ProcessIdentifier (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn, int iKWCode)
    ProcessInlineStatement
 */
 
-void ProcessInlineStatement (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn, int iKWCode)
+void ProcessInlineStatement (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn, 
+                             int iKWCode)
 {
   PINPUTINFO pinfo;
 
@@ -321,15 +309,15 @@ void ProcessWord (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn)
     return;
 
   pinfo = (PINPUTINFO) pibIn->pInfo;
-  
+
   iKWCode = GetKeywordCode (szLex, &fContext);
 
-  assert(pinfo->wContext != CN_END);
+  assert (pinfo->wContext != CN_END);
 
   if ((pinfo->wContext == CN_END) ||   /* Beyond valid input ! */
       (iKWCode &&                      /* Is a keyword */
        !(fContext & pinfo->wContext))) /* In a valid context */
-    ReportError (pibIn, RE_BADCONTEXT, szLex, NULL);
+    ReportError (pibIn, RE_BADCONTEXT | RE_FATAL, szLex, NULL);
 
   else {
     switch (iKWCode) {
@@ -340,6 +328,7 @@ void ProcessWord (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn)
       case KM_STATES:
       case KM_INPUTS:
       case KM_OUTPUTS:
+      case KM_COMPARTMENTS:
         if (GetPunct (pibIn, szPunct, '=')) {
           if (GetPunct (pibIn, szPunct, CH_LBRACE))
             GetVarList(pibIn, szLex, iKWCode);
@@ -371,6 +360,32 @@ void ProcessWord (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn)
         ProcessInlineStatement (pibIn, szLex, szEqn, iKWCode);
         break;
 
+      case KM_SBMLMODELS:
+        if (GetPunct (pibIn, szPunct, '=')) {
+          if (GetPunct (pibIn, szPunct, CH_LBRACE)) {
+            printf ("\nmod: merging several SBML models\n"); 
+            ReadSBMLModels (pibIn);
+          }
+          else
+            ReportError (pibIn, RE_EXPECTED | RE_FATAL, "{", NULL);
+        }
+        else
+          ReportError (pibIn, RE_EXPECTED | RE_FATAL, "=", NULL);
+        break;
+
+      case KM_PKTEMPLATE:
+        if (GetPunct (pibIn, szPunct, '=')) {
+          if (GetPunct (pibIn, szPunct, CH_LBRACE)) {
+            printf ("\nmod: reading pharmacokinetic template "); 
+            ReadPKTemplate (pibIn);
+          }
+          else
+            ReportError (pibIn, RE_EXPECTED | RE_FATAL, "{", NULL);
+        }
+        else
+          ReportError (pibIn, RE_EXPECTED | RE_FATAL, "=", NULL);
+        break;
+
       default: /* Not a keyword, process identifier */
         ProcessIdentifier (pibIn, szLex, szEqn, iKWCode);
         break;
@@ -392,18 +407,19 @@ void ProcessWord (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn)
    the syntax described above and in the documentation.
 */
 
-void ReadModel (PINPUTINFO pinfo, PSTR szFullPathname)
+void ReadModel (PINPUTINFO pinfo, PINPUTINFO ptempinfo, PSTR szFileIn)
 {
   INPUTBUF ibIn;
   PSTRLEX szLex; /* Lex elem of MAX_LEX length */
   PSTREQN szEqn; /* Equation buffer of MAX_EQN length */
   int iLexType;
-  
-  if (!InitBuffer (&ibIn, szFullPathname))
+
+  if (!InitBuffer (&ibIn, BUFFER_SIZE, szFileIn))
     ReportError (&ibIn, RE_INIT | RE_FATAL, "ReadModel", NULL);
 
-  InitInfo (pinfo, szFullPathname);
-  ibIn.pInfo = (PVOID) pinfo; /* Attach info rec to input buffer */
+  /* Attach info records to input buffer */
+  ibIn.pInfo = (PVOID) pinfo;
+  ibIn.pTempInfo = (PVOID) ptempinfo;
 
   do { /* State machine for parsing syntax */
     NextLex (&ibIn, szLex, &iLexType);
@@ -445,15 +461,11 @@ void ReadModel (PINPUTINFO pinfo, PSTR szFullPathname)
         break; 
  
     } /* switch */
-    
+
   } while (pinfo->wContext != CN_END && 
-           (*ibIn.pbufCur || FillBuffer (&ibIn) != EOF));
+           (*ibIn.pbufCur || FillBuffer (&ibIn, BUFFER_SIZE) != EOF));
 
   pinfo->wContext = CN_END; 
   fclose (ibIn.pfileIn);
 
 } /* ReadModel */
-  
-
-  
-  
