@@ -1,10 +1,7 @@
 /* ----------------------------------------------------------------------------
    modo.c
 
-   written by Don Maszle
-   21 September 1991
-   
-   Copyright (c) 1993.  Don Maszle, Frederic Bois.
+   Copyright (c) 1993-2008. Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -130,7 +127,7 @@ int WriteOneName (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
   if (pvm->szEqn != vszHasInitializer) { /* These appear later */
     fprintf (pfile, "     %s", pvm->szName);
     if (TYPE(pvm) != ID_INPUT)
-      fprintf (pfile, " %s %s\n", (pvm->szEqn ? ":=" : "->"),
+      fprintf (pfile, " %s %s;\n", (pvm->szEqn ? "=" : "->"),
                (pvm->szEqn ? pvm->szEqn : "0.0"));
     else
       fprintf (pfile, " (is a function)\n");
@@ -215,9 +212,9 @@ void WriteIncludes (PFILE pfile)
 */
 int WriteOneDecl (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
 {
-  assert(TYPE(pvm) != ID_INPUT);
-  assert(TYPE(pvm) != ID_OUTPUT);
-  assert(TYPE(pvm) != ID_STATE);
+  assert (TYPE(pvm) != ID_INPUT);
+  assert (TYPE(pvm) != ID_OUTPUT);
+  assert (TYPE(pvm) != ID_STATE);
 
   if (TYPE(pvm) > ID_PARM) fprintf (pfile, "  /* local */ ");
 
@@ -308,7 +305,8 @@ void WriteDecls (PFILE pfile, PVMMAPSTRCT pvmGlo)
    The name is determined by hType if hType is non-NULL.  If hType is
    NULL, then the type is taken to be the hType field of pvm.
 */
-PSTR GetName (PVMMAPSTRCT pvm, PSTR szModelVarName, PSTR szDerivName, HANDLE hType)
+PSTR GetName (PVMMAPSTRCT pvm, PSTR szModelVarName, PSTR szDerivName, 
+              HANDLE hType)
 {
 static PSTRLEX vszVarName;
   HANDLE hTypeToUse = (hType ? hType : TYPE(pvm));
@@ -358,7 +356,7 @@ int WriteOneVMEntry (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
     return 0;
   }
     
-  assert(iType && \
+  assert (iType && \
     iType != ID_LOCALDYN && iType != ID_LOCALSCALE && iType != ID_LOCALJACOB);
 
   if (pvm->szEqn != vszHasInitializer) { /* These appear later */
@@ -373,7 +371,7 @@ int WriteOneVMEntry (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
 
     return (1);
 
-  }  /* if */
+  } /* if */
 
   return 0;
 
@@ -657,7 +655,7 @@ void WriteCalcDeriv (PFILE pfile, PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmDyn)
 
   ForAllVar (pfile, pvmGlo, &WriteOneDecl, ID_LOCALDYN, NULL);
 
-  fprintf (pfile, "\n  CalcInputs (pdTime); /* Get new input vals */\n");
+  fprintf (pfile, "\n  CalcInputs (pdTime); /* Get new input vals */\n\n");
 
   ForAllVar (pfile, pvmDyn, &WriteOneEquation, ALL_VARS, (PVOID) KM_DYNAMICS); 
  
@@ -700,6 +698,7 @@ void WriteCalcJacob (PFILE pfile, PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmJacob)
   ForAllVar (pfile, pvmGlo, &WriteOneDecl, ID_LOCALJACOB, NULL);
   ForAllVar (pfile, pvmJacob, &WriteOneEquation, ALL_VARS, (PVOID) KM_JACOB);  
   fprintf (pfile, "\n} /* CalcJacob */\n\n\n");
+
 } /* WriteCalcJacob */
 
 
@@ -793,7 +792,7 @@ void IndexVariables (PVMMAPSTRCT pvmGlo)
   
   iIndex = vnStates + vnOutputs + vnInputs;
   ForAllVar (NULL, pvmGlo, &IndexOneVar, ID_PARM, (PVOID) &iIndex);
-  
+
 } /* IndexVariables */
 
 
@@ -930,30 +929,6 @@ void VerifyEqns (PVMMAPSTRCT pvmGlo, PVMMAPSTRCT pvmDyn)
 
 } /* VerifyEqns */
 
-void MakeCodeFilename (PSTR szNewName, PSTR szName)
-{
-  strcpy (szNewName, szName);
-
-#ifdef _DOS_
-  /* In Dos, you can only have one '.' in a filename */
-  strtok (szNewName, ".");  /* Remove any extension */
-  strcat (szNewName, ".c");  /* Create ".c" filename */
-
-#else
-  {
-  int cchName;
-
-  cchName = strlen (szNewName);
-  if (!((cchName > 1)
-      && (szNewName[cchName-1] == 'c')
-      && (szNewName[cchName-2] == '.'))) /* Look for current extension */
-    strcat (szNewName, ".c"); /* Create ".c" filename */
-  } /* block */
-
-#endif
-
-} /* MakeCodeFilename */
-  
 
 /* ----------------------------------------------------------------------------
    WriteModel
@@ -961,17 +936,15 @@ void MakeCodeFilename (PSTR szNewName, PSTR szName)
    Writes the model calculation file szOutFilename for the parameters
    and dynamic equations given.
 */
-void WriteModel (PINPUTINFO pinfo, int nArg, PSTR rgszArgs[])
+void WriteModel (PINPUTINFO pinfo, PSTR szFileOut)
 {
   PFILE pfile;
-  char szFileWithExt[FILENAME_MAX];
-  static char vszFilenameDefault[] = "model.c";
 
   if (!pinfo->pvmGloVars || (!pinfo->pvmDynEqns && !pinfo->pvmCalcOutEqns)) {
     printf ("Error: No Dynamics, no outputs or no global variables defined\n");
     return;
   }
-  
+
   ReversePointers (&pinfo->pvmGloVars);
   ReversePointers (&pinfo->pvmDynEqns);
   ReversePointers (&pinfo->pvmScaleEqns);
@@ -983,22 +956,14 @@ void WriteModel (PINPUTINFO pinfo, int nArg, PSTR rgszArgs[])
   AdjustVarHandles (pinfo->pvmGloVars);
   VerifyEqns (pinfo->pvmGloVars, pinfo->pvmDynEqns);
 
-  MakeCodeFilename (szFileWithExt, 
-                    (nArg > 2 ? rgszArgs[2] : vszFilenameDefault));
-
-  pfile = fopen (szFileWithExt, "w");
+  pfile = fopen (szFileOut, "w");
   if (pfile) {
 
     /* Keep track of the model description file and generator name */
     vszModelFilename = pinfo->szInputFilename;
-
-#ifdef _MACOS_
-    vszModGenName = "Mod";
-#else
-    vszModGenName = rgszArgs[0];
-#endif
+    vszModGenName = pinfo->szModGenName;
     
-    WriteHeader (pfile, szFileWithExt, pinfo->pvmGloVars);
+    WriteHeader (pfile, szFileOut, pinfo->pvmGloVars);
 
     WriteIncludes (pfile);
     WriteDecls (pfile, pinfo->pvmGloVars);
@@ -1012,12 +977,12 @@ void WriteModel (PINPUTINFO pinfo, int nArg, PSTR rgszArgs[])
 
     fclose (pfile);
 
-    printf ("\n* Created model file '%s'\n", szFileWithExt);
+    printf ("\n* Created model file '%s'.\n\n", szFileOut);
 
   } /* if */
   else
     ReportError (NULL, RE_CANNOTOPEN | RE_FATAL,
-                 szFileWithExt, "...in WriteModel ()");
+                 szFileOut, "...in WriteModel ()");
 
 } /* WriteModel */
 
