@@ -3,73 +3,73 @@
 
    Model File:  perc.model
 
-   Date:  Tue Jan 29 14:51:16 2008
+   Date:  Sun Jan 11 23:51:12 2009
 
-   Created by:  "../../mod/mod v5.1.0"
+   Created by:  "../../mod/mod v5.3.0"
     -- a model preprocessor by Don Maszle
    ___________________________________________________
 
-   Copyright (c) 1993-2006 by F. Bois & D. Maszle.
+   Copyright (c) 1993-2008 Free Software Foundation, Inc.
 
    Model calculations for compartmental model:
 
    6 States:
-     Q_fat -> 0.0
-     Q_wp -> 0.0
-     Q_pp -> 0.0
-     Q_liv -> 0.0
-     Q_exh -> 0.0
-     Q_met -> 0.0
+     Q_fat -> 0.0;
+     Q_wp -> 0.0;
+     Q_pp -> 0.0;
+     Q_liv -> 0.0;
+     Q_exh -> 0.0;
+     Q_met -> 0.0;
 
    6 Outputs:
-     C_liv -> 0.0
-     C_alv -> 0.0
-     C_exh -> 0.0
-     C_ven -> 0.0
-     Pct_metabolized -> 0.0
-     C_exh_ug -> 0.0
+     C_liv -> 0.0;
+     C_alv -> 0.0;
+     C_exh -> 0.0;
+     C_ven -> 0.0;
+     Pct_metabolized -> 0.0;
+     C_exh_ug -> 0.0;
 
    2 Inputs:
      C_inh (is a function)
      Q_ing (is a function)
 
    36 Parameters:
-     PPM_per_mg_per_l := 72.0 / 0.488
-     mg_per_l_per_PPM := 1/PPM_per_mg_per_l
-     InhMag := 0.0
-     Period := 0.0
-     Exposure := 0.0
-     IngDose := 0.0
-     LeanBodyWt := 55
-     Pct_M_fat := .16
-     Pct_LM_liv := .03
-     Pct_LM_wp := .17
-     Pct_LM_pp := .70
-     Pct_Flow_fat := .09
-     Pct_Flow_liv := .34
-     Pct_Flow_wp := .50
-     Pct_Flow_pp := .07
-     PC_fat := 144
-     PC_liv := 4.6
-     PC_wp := 8.7
-     PC_pp := 1.4
-     PC_art := 12.0
-     Flow_pul := 8.0
-     Vent_Perf := 1.14
-     sc_Vmax := .0026
-     Km := 1.0
-     BodyWt := 0
-     V_fat := 0
-     V_liv := 0
-     V_wp := 0
-     V_pp := 0
-     Flow_fat := 0
-     Flow_liv := 0
-     Flow_wp := 0
-     Flow_pp := 0
-     Flow_tot := 0
-     Flow_alv := 0
-     Vmax := 0
+     PPM_per_mg_per_l = 72.0 / 0.488;
+     mg_per_l_per_PPM = 1/PPM_per_mg_per_l;
+     InhMag = 0.0;
+     Period = 0.0;
+     Exposure = 0.0;
+     IngDose = 0.0;
+     LeanBodyWt = 55;
+     Pct_M_fat = .16;
+     Pct_LM_liv = .03;
+     Pct_LM_wp = .17;
+     Pct_LM_pp = .70;
+     Pct_Flow_fat = .09;
+     Pct_Flow_liv = .34;
+     Pct_Flow_wp = .50;
+     Pct_Flow_pp = .07;
+     PC_fat = 144;
+     PC_liv = 4.6;
+     PC_wp = 8.7;
+     PC_pp = 1.4;
+     PC_art = 12.0;
+     Flow_pul = 8.0;
+     Vent_Perf = 1.14;
+     sc_Vmax = .0026;
+     Km = 1.0;
+     BodyWt = 0;
+     V_fat = 0;
+     V_liv = 0;
+     V_wp = 0;
+     V_pp = 0;
+     Flow_fat = 0;
+     Flow_liv = 0;
+     Flow_wp = 0;
+     Flow_pp = 0;
+     Flow_tot = 0;
+     Flow_alv = 0;
+     Vmax = 0;
 */
 
 
@@ -147,7 +147,7 @@
 /* For export. Keep track of who we are. */
 char szModelDescFilename[] = "perc.model";
 char szModelSourceFilename[] = __FILE__;
-char szModelGenAndVersion[] = "../../mod/mod v5.1.0";
+char szModelGenAndVersion[] = "../../mod/mod v5.3.0";
 
 /* Externs */
 extern BOOL vbModelReinitd;
@@ -371,9 +371,13 @@ void CalcDeriv (double  rgModelVars[], double  rgDerivs[], PDOUBLE pdTime)
 
   CalcInputs (pdTime); /* Get new input vals */
 
+
   Cout_fat = rgModelVars[ID_Q_fat] / ( V_fat * PC_fat ) ;
+
   Cout_wp = rgModelVars[ID_Q_wp] / ( V_wp * PC_wp ) ;
+
   Cout_pp = rgModelVars[ID_Q_pp] / ( V_pp * PC_pp ) ;
+
   Cout_liv = rgModelVars[ID_Q_liv] / ( V_liv * PC_liv ) ;
 
   dQ_ven = Flow_fat * Cout_fat + Flow_wp * Cout_wp + Flow_pp * Cout_pp + Flow_liv * Cout_liv ;
@@ -389,9 +393,13 @@ void CalcDeriv (double  rgModelVars[], double  rgDerivs[], PDOUBLE pdTime)
   dQmet_liv = Vmax * rgModelVars[ID_Q_liv] / ( Km + rgModelVars[ID_Q_liv] ) ;
 
   rgDerivs[ID_Q_exh] = Flow_alv * rgModelVars[ID_C_alv] ;
+
   rgDerivs[ID_Q_fat] = Flow_fat * ( C_art - Cout_fat ) ;
+
   rgDerivs[ID_Q_wp] = Flow_wp * ( C_art - Cout_wp ) ;
+
   rgDerivs[ID_Q_pp] = Flow_pp * ( C_art - Cout_pp ) ;
+
   rgDerivs[ID_Q_liv] = vrgInputs[ID_Q_ing].dVal + Flow_liv * ( C_art - Cout_liv ) - dQmet_liv ;
 
   rgDerivs[ID_Q_met] = dQmet_liv ;
