@@ -3,7 +3,7 @@
    written by Frederic Bois
    5 January 1996
 
-   Copyright (c) 1996-2004.  Frederic Bois.
+   Copyright (c) 1996-2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -483,7 +483,8 @@ void DoMarkov (PANALYSIS panal)
 
   if (pgd->nInitIter == 3) { /* tempered */
     for (i = 0; i < NTEMP ; i++) {
-      CTemp[i] = dlnPi[i] = 0;
+      CTemp[i] = 0; 
+      dlnPi[i] = 0;
     }
   }
 
@@ -1257,8 +1258,7 @@ double LnDensity (PMCVAR pMCVar, PANALYSIS panal)
       /* Normal log-density minus log-jacobian */
       return lnDFNormal( dTmp4, dTmp3, dTmp ) - 0.5*log(pow(dTmp4,2) + dTmp2);
 
-    case MCV_STUDENTT: /* Student T */
-	               /* dParm1 is dof, dParm2 is m, dMin is sigma */
+    case MCV_STUDENTT: /* Student T, dParm1 is dof, dParm2 is m, dMin is sigma */
       if (dParm1 <= 0) {
         printf ("Error: bad dof for Student-T variate"
 		"in LnDensity\n");
@@ -1269,6 +1269,10 @@ double LnDensity (PMCVAR pMCVar, PANALYSIS panal)
 	      -0.5 * log(dParm1 * PI *dMin *dMin)
 	      -dTmp * log(1 + pow((dTheta - dParm2) / dMin, 2) / dParm1));
 
+    case MCV_CAUCHY:
+    case MCV_HALFCAUCHY: /* dParm1 is scale */
+      return (- log(PI * (dParm1 + dTheta * dTheta / dParm1)));
+
     default:
       ReportRunTimeError(panal, RE_UNKNOWNDIST | RE_FATAL, "LnDensity");
 
@@ -1415,11 +1419,11 @@ double MaxMCVar (PMCVAR pMCVar) {
 double MinMCVar (PMCVAR pMCVar) {
 
   /* if the parameter has a discrete distribution, round it - FB 12/06/97 */
-  if (pMCVar->iType == MCV_BINOMIAL || pMCVar->iType == MCV_POISSON ) {
+  if (pMCVar->iType == MCV_BINOMIAL || pMCVar->iType == MCV_POISSON) {
    return( *(pMCVar->pdParm[2]));                                 
   }
   else { /* FB fixed the uniform case - FB 30/06/97 */
-    if (pMCVar->iType == MCV_UNIFORM || pMCVar->iType == MCV_LOGUNIFORM ) {
+    if (pMCVar->iType == MCV_UNIFORM || pMCVar->iType == MCV_LOGUNIFORM) {
       return( *(pMCVar->pdParm[0]));
     }
     else {
