@@ -3,7 +3,7 @@
    written by Don Maszle
    7 October 1991
 
-   Copyright (c) 1991-2004.  Don Maszle, Frederic Bois.
+   Copyright (c) 1991-2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -353,10 +353,10 @@ void UpdateInputs (PDOUBLE pdTime, PDOUBLE pdNextTransTime)
   double dT; /* New time to try */
   int i;
 
-  if (vbModelReinitd) {         /* If model has been re-initialized */
-    FixupDependentInputs ();    /* Fixup input fields dependent on vars */
-    ScaleModel();               /* ...then scale the model parms */
-    GetStartPeriods (pdTime);   /* Initialize the current period */
+  if (vbModelReinitd) {         /* if model has been re-initialized */
+    ScaleModel();               /* scale the model parms */
+    FixupDependentInputs ();    /* fixup input fields dependent on vars */
+    GetStartPeriods (pdTime);   /* initialize the current period */
   }
 
   dT = *pdNextTransTime = DBL_MAX;
