@@ -3,7 +3,7 @@
    written by Frederic Bois
    16 August 1997
 
-   Copyright (c) 1997-2004.  Don Maszle, Frederic Bois.
+   Copyright (c) 1997-2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -623,8 +623,9 @@ void Importance_Resample (long nSims, long *pIndex0, long *pIndex1,
 
   j = 0;
   do {    
-    /* randomly pick a vector among the nSims available */
-    i = floor (Randoms() * nSims);
+    /* randomly pick a vector among the nSims available. No risk of 
+       overflow because Randoms() is between 0 and 1 */
+    i = (long) floor (Randoms() * nSims);
 
     if (Randoms() < pdL[i]) { /* accept */
       pIndex1[j] = pIndex0[i];
