@@ -1,10 +1,6 @@
 /* random.h
 
-   written by Frederic Bois
-   modifications by Don Robert Maszle
-   8 January 1992
-
-   Copyright (c) 1992-2004.  Don Maszle, Frederic Bois.
+   Copyright (c) 1992-2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -33,9 +29,6 @@
 
    Gives prototypes for random functions.
 
-   2005-09-06: Weihsueh A. Chiu (WAC) -- added generalized lognormal and
-   student T routines header (GenLogNormalRandom and StudentTRandom).
-
 */
 
 #ifndef _RANDOM_H_
@@ -72,6 +65,7 @@ double Randoms (void);
 double BetaRandom (double alpha, double beta, double a, double b);
 double BinomialBetaRandom (double Expectation, double alpha, double beta);
 double BinomialRandom (double p, long n);
+double CauchyRandom (double dScale);
 double Chi2Random (double dof);
 double ExpRandom (double beta);
 double InvGGammaRandom (double alpha, double beta);
