@@ -1,6 +1,6 @@
 /* sim.c
 
-   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.
+   Copyright (c) 1993-2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -225,11 +225,6 @@ int DoOneExperiment (PEXPERIMENT pexp)
   /* Iterate to final time */
   while (pexp->dTime < pexp->dTfinal) {
 
-#ifdef _MACOSLEVEL2_
-    /* this allows background processing on the Macintosh */
-    HandleEvent();
-#endif
-
     /* If dynamics equations are defined */
     if (pmod->nStates > 0) {
 
@@ -244,6 +239,11 @@ int DoOneExperiment (PEXPERIMENT pexp)
 
       dTup = (dTout < dTtrans) ? dTout : dTtrans;
 
+      /* F. Bois, 07 October 2008: same rounding problem fix: */
+      if (fabs(dTup - pexp->dTime) < DBL_EPSILON * 2.0 * 
+                                     mymax(fabs(dTup), fabs(pexp->dTime)))
+        pexp->dTime = dTup;
+
       if (pis->iAlgo == IAL_LSODES) { /* Lsodes algorithm */
 
         pis->rwork[0] = dTup; /* do not overshoot dTup - FB 01/07/97 */
