@@ -2,7 +2,7 @@
 
    originally written by Don Maszle
 
-   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.
+   Copyright (c) 1993-2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -50,8 +50,8 @@
 */
 
 /* Version and copyright */
-#define VSZ_VERSION "v5.1.0"
-#define VSZ_COPYRIGHT "Copyright (c) 1993-2006 by F. Bois & D. Maszle.  All rights reserved."
+#define VSZ_VERSION "v5.3.0"
+#define VSZ_COPYRIGHT "Copyright (c) 1993-2008 Free Software Foundation, Inc."
 
 /* These are potential array size problems.
    Other maximum sizes are MAX_EQN and MAX_LEX in lex.h */
@@ -115,11 +115,10 @@
 #define KM_BINOMIALBETA    228
 #define KM_HALFNORMAL      229
 #define KM_TRUNCINVGGAMMA  230
-/* WAC -- added Generalized Lognormal and Student T -- 2005-09-06 */
 #define KM_GENLOGNORMAL    231    
 #define KM_STUDENTT        232
-
-
+#define KM_CAUCHY          233
+#define KM_HALFCAUCHY      234
 
 #define KM_PREDICTION      300
 
@@ -172,9 +171,10 @@
 #define MCV_BINOMIALBETA    18
 #define MCV_HALFNORMAL      19
 #define MCV_TRUNCINVGGAMMA  20
-/* WAC -- added Generalized Lognormal and Student T -- 2005-09-06 */
 #define MCV_GENLOGNORMAL    21
 #define MCV_STUDENTT        22
+#define MCV_CAUCHY          23
+#define MCV_HALFCAUCHY      24
 
 /* Integration Method types */
 
