@@ -1,9 +1,6 @@
 /* simi.c
 
-   written by Don Maszle
-   16 October 1991
-
-   Copyright (c) 1991-2004.  Don Maszle, Frederic Bois.
+   Copyright (c) 1991-2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -37,6 +34,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <limits.h>
 
 #include "lexerr.h"
 #include "list.h"
@@ -100,29 +98,31 @@ KM vrgkmKeywordMap[] = { /* Global Keyword - code map */
   {"No",            KM_NO,          CN_FUNCARG},   /* Use YesNoFromLex() */
   {"Yes",           KM_YES,         CN_FUNCARG},
 
-  {"Uniform",         KM_UNIFORM,         CN_FUNCARG}, /* Use McvFromLex() */
-  {"LogUniform",      KM_LOGUNIFORM,      CN_FUNCARG},
-  {"Beta",            KM_BETA,            CN_FUNCARG},
-  {"Normal",          KM_NORMAL,          CN_FUNCARG},
-  {"HalfNormal",      KM_HALFNORMAL,      CN_FUNCARG},
-  {"LogNormal",       KM_LOGNORMAL,       CN_FUNCARG},
-  {"TruncNormal",     KM_TRUNCNORMAL,     CN_FUNCARG},
-  {"TruncLogNormal",  KM_TRUNCLOGNORMAL,  CN_FUNCARG},
-  {"Chi2",            KM_CHI2,            CN_FUNCARG},
+  {"Beta",            KM_BETA,            CN_FUNCARG}, /* Use McvFromLex() */
   {"Binomial",        KM_BINOMIAL,        CN_FUNCARG},
-  {"Piecewise",       KM_PIECEWISE,       CN_FUNCARG},
+  {"BinomialBeta",    KM_BINOMIALBETA,    CN_FUNCARG},
+  {"Cauchy",          KM_CAUCHY,          CN_FUNCARG},
+  {"Chi2",            KM_CHI2,            CN_FUNCARG},
   {"Exponential",     KM_EXPONENTIAL,     CN_FUNCARG},
   {"Gamma",           KM_GGAMMA,          CN_FUNCARG},
-  {"Poisson",         KM_POISSON,         CN_FUNCARG},
-  {"InvGamma",        KM_INVGGAMMA,       CN_FUNCARG},
-  {"TruncInvGamma",   KM_TRUNCINVGGAMMA,  CN_FUNCARG},
-  {"Normal_v",        KM_NORMALV,         CN_FUNCARG},
-  {"LogNormal_v",     KM_LOGNORMALV,      CN_FUNCARG},
-  {"TruncNormal_v",   KM_TRUNCNORMALV,    CN_FUNCARG},
-  {"TruncLogNormal_v",KM_TRUNCLOGNORMALV, CN_FUNCARG},
-  {"BinomialBeta",    KM_BINOMIALBETA,    CN_FUNCARG},
   {"GenLogNormal",    KM_GENLOGNORMAL,    CN_FUNCARG}, 
+  {"HalfCauchy",      KM_HALFCAUCHY,      CN_FUNCARG},
+  {"HalfNormal",      KM_HALFNORMAL,      CN_FUNCARG},
+  {"InvGamma",        KM_INVGGAMMA,       CN_FUNCARG},
+  {"LogNormal",       KM_LOGNORMAL,       CN_FUNCARG},
+  {"LogNormal_v",     KM_LOGNORMALV,      CN_FUNCARG},
+  {"LogUniform",      KM_LOGUNIFORM,      CN_FUNCARG},
+  {"Normal",          KM_NORMAL,          CN_FUNCARG},
+  {"Normal_v",        KM_NORMALV,         CN_FUNCARG},
+  {"Piecewise",       KM_PIECEWISE,       CN_FUNCARG},
+  {"Poisson",         KM_POISSON,         CN_FUNCARG},
   {"StudentT",        KM_STUDENTT,        CN_FUNCARG},
+  {"TruncInvGamma",   KM_TRUNCINVGGAMMA,  CN_FUNCARG},
+  {"TruncLogNormal",  KM_TRUNCLOGNORMAL,  CN_FUNCARG},
+  {"TruncLogNormal_v",KM_TRUNCLOGNORMALV, CN_FUNCARG},
+  {"TruncNormal",     KM_TRUNCNORMAL,     CN_FUNCARG},
+  {"TruncNormal_v",   KM_TRUNCNORMALV,    CN_FUNCARG},
+  {"Uniform",         KM_UNIFORM,         CN_FUNCARG},
 
   {"Prediction",    KM_PREDICTION,        CN_FUNCARG},
 
@@ -268,6 +268,8 @@ int McvFromLex (PSTR szLex)
              : ikwcode == KM_BINOMIALBETA   ? MCV_BINOMIALBETA
              : ikwcode == KM_GENLOGNORMAL   ? MCV_GENLOGNORMAL 
              : ikwcode == KM_STUDENTT       ? MCV_STUDENTT 
+             : ikwcode == KM_CAUCHY         ? MCV_CAUCHY 
+             : ikwcode == KM_HALFCAUCHY     ? MCV_HALFCAUCHY 
              : (-1));
 
   return iReturn;
@@ -617,7 +619,7 @@ BOOL GetPrintStep (PINPUTBUF pibIn, PSTR szLex, POUTSPEC pos)
 {
   PPRINTREC pprintrec;
   HVAR hvar = 0;
-  double dStart = 0, dEnd = 0, dStep = 0;
+  double dStart = 0, dEnd = 0, dStep = 0, dTmp;
   long i;
 
   static int vrgiIntArgTypes[4] /* 3 PrintStep arguments */
@@ -655,7 +657,12 @@ BOOL GetPrintStep (PINPUTBUF pibIn, PSTR szLex, POUTSPEC pos)
 
     pprintrec->hvar = hvar;
 
-    pprintrec->cTimes = 1 + ceil((dEnd - dStart) / dStep);
+    /* F. Bois, Oct 9 2008: fix an unlikely overflow */
+    dTmp = 1 + ceil((dEnd - dStart) / dStep);
+    if (dTmp < LONG_MAX)
+      pprintrec->cTimes = (long) dTmp;
+    else
+      pprintrec->cTimes = LONG_MAX;
 
     if ( !(pprintrec->pdTimes = InitdVector (pprintrec->cTimes)))
       ReportError (pibIn, RE_OUTOFMEM | RE_FATAL, "GetPrintStep", NULL);
@@ -1058,7 +1065,7 @@ int GetDistribSpec (PINPUTBUF pibIn, PANALYSIS panal, PSTR szLex)
     goto Exit_MCVarySpec;
   }
 
-  /* Get the Distrib() spec.  Check syntax at each element. */
+  /* Get the Distrib() spec. Check syntax at each element. */
   
   /* Get the parameter to be varied */
   if ((iErr = (EGetPunct (pibIn, szLex, CH_LPAREN) || 
@@ -1357,6 +1364,30 @@ int GetDistribSpec (PINPUTBUF pibIn, PANALYSIS panal, PSTR szLex)
 
       break;
 
+    /* ----------------------------------------------------------------------*/
+    case MCV_CAUCHY:     /* one parameter: scale */
+
+       if ((iErr = GetDistribParam (pibIn, szLex, plist, 0, pMCVar)))
+        goto Done_GetMCVary;
+
+      pMCVar->dParm[1] = DBL_MAX;
+      pMCVar->dParm[2] = -DBL_MAX;
+      pMCVar->dParm[3] = DBL_MAX;
+
+      break;
+
+    /* ----------------------------------------------------------------------*/
+    case MCV_HALFCAUCHY: /* one parameter: scale */
+
+       if ((iErr = GetDistribParam (pibIn, szLex, plist, 0, pMCVar)))
+        goto Done_GetMCVary;
+
+      pMCVar->dParm[1] = DBL_MAX / 2;
+      pMCVar->dParm[2] = 0;
+      pMCVar->dParm[3] = DBL_MAX;
+
+      break;
+
     /* ----------------------------------------------------------------------*/
     default:
         ReportRunTimeError(panal, RE_UNKNOWNDIST | RE_FATAL, "GetDistribSpec");
@@ -1394,7 +1425,6 @@ Done_GetMCVary: ;
     }
     
     ReportError(pibIn, RE_SYNTAXERR | RE_FATAL, NULL, NULL);
-
   }
 
 Exit_MCVarySpec: ;
