@@ -1,9 +1,6 @@
 /* siminit.c
 
-   written by Don Maszle
-   22 November 1991
-
-   Copyright (c) 1991-2004.  Don Maszle, Frederic Bois.
+   Copyright (c) 1991-2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
