@@ -1,9 +1,8 @@
 /* strutil.c
 
-   written by Don Robert Maszle
-   12 January 1992
-
-   Copyright (c) 1992-2004.  Don Maszle, Frederic Bois.
+   originally written by Don Robert Maszle
+ 
+   Copyright (c) 1992-2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
