@@ -1,9 +1,8 @@
 /* strutil.h
 
-   written by Don Robert Maszle
-   27 January 1992
+   originally written by Don Robert Maszle
 
-   Copyright (c) 1992-2004.  Don Maszle, Frederic Bois.
+   Copyright (c) 1992-2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
