@@ -1,8 +1,8 @@
 /* yourcode.c
 
-   written by Frederic Bois
+   originally written by Frederic Bois
    
-   Copyright (c) 1993-2004.  Don Maszle, Frederic Bois.
+   Copyright (c) 1993-2008 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
